package com.atguigu.ssyx.acl.service.impl;

import com.atguigu.ssyx.acl.mapper.AdminRoleMapper;
import com.atguigu.ssyx.acl.service.AdminRoleService;
import com.atguigu.ssyx.acl.service.RoleService;
import com.atguigu.ssyx.model.acl.AdminRole;
import com.atguigu.ssyx.model.acl.Role;
import com.atguigu.ssyx.vo.acl.AssignAdminRoleVo;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.ArrayList;
import java.util.List;

@Service
public class AdminRoleServiceImpl extends ServiceImpl<AdminRoleMapper, AdminRole> implements AdminRoleService {
    @Autowired
    private RoleService roleService;

    /**
     * 根据用户获取角色数据
     *
     * @param adminId 用户ID
     * @return 分配集合
     */
    @Override
    public AssignAdminRoleVo findRoleByUserId(Long adminId) {
        // 查询所有的角色
        List<Role> allRolesList = roleService.list(null);
        List<Role> roleList = baseMapper.findRoleByUserId(adminId);

        return AssignAdminRoleVo.builder().assignRoles(roleList).allRolesList(allRolesList).build();
    }

    /**
     * * 根据用户分配角色
     *
     * @param adminId 用户ID
     * @param roleIds 角色ID
     */
    @Override
    @Transactional
    public void saveUserRoleShip(Long adminId, Long[] roleIds) {
        remove(Wrappers.<AdminRole>lambdaQuery().eq(AdminRole::getAdminId, adminId));
        ArrayList<AdminRole> adminRoles = new ArrayList<>();

        // 循环遍历并插入
        for (Long roleId : roleIds) {
            AdminRole adminRole = new AdminRole();
            adminRole.setAdminId(adminId);
            adminRole.setRoleId(roleId);
            adminRoles.add(adminRole);
        }
        
        // 插入整体数据
        saveBatch(adminRoles);
    }
}
